
Sending data/parameters to untrusted devices
-------

**Description:**

Whenever an application sends data/parameters to untrusted devices this data could be 
compromised if the device has malicious intents.


**Solution:**

Verify the application minimises the number of parameters sent to untrusted systems, 
such as hidden fields, Ajax variables, cookies and header values.

	